@@ -21,8 +21,8 @@ if ( grep /\P{ASCII}/ => @ARGV ) {
 
 # Useful common code
 use autodie;
-use Carp         qw( carp croak confess cluck );
-use English      qw( -no_match_vars );
+use Carp qw( carp croak confess cluck );
+use English qw( -no_match_vars );
 use Data::Dumper qw( Dumper );
 
 # give a full stack dump on any untrapped exceptions
@@ -52,35 +52,11 @@ sub new {
 
 sub as_text {
     my $self = shift;
-    if ( exists $self->{ 'ival' } ) {
-        return $self->{ 'ival' }->{ 'ival' } // 0;
-    }
-    if ( $self->{ 'isnull' } ) {
-        return 'NULL';
-    }
-    if ( exists $self->{ 'sval' } ) {
-        return $self->quote_literal( $self->{ 'sval' }->{ 'sval' } // '' );
-    }
-    if ( exists $self->{ 'boolval' } ) {
-        return $self->{ 'boolval' }->{ 'boolval' } ? 'true' : 'false';
-    }
     return $self->{ 'val' }->as_text;
 }
 
 sub pretty_print {
     my $self = shift;
-    if ( exists $self->{ 'ival' } ) {
-        return $self->{ 'ival' }->{ 'ival' } // 0;
-    }
-    if ( $self->{ 'isnull' } ) {
-        return 'NULL';
-    }
-    if ( exists $self->{ 'sval' } ) {
-        return $self->quote_literal( $self->{ 'sval' }->{ 'sval' } // '' );
-    }
-    if ( exists $self->{ 'boolval' } ) {
-        return $self->{ 'boolval' }->{ 'boolval' } ? 'true' : 'false';
-    }
     return $self->{ 'val' }->pretty_print;
 }
 
