@@ -21,8 +21,8 @@ if ( grep /\P{ASCII}/ => @ARGV ) {
 
 # Useful common code
 use autodie;
-use Carp         qw( carp croak confess cluck );
-use English      qw( -no_match_vars );
+use Carp qw( carp croak confess cluck );
+use English qw( -no_match_vars );
 use Data::Dumper qw( Dumper );
 
 # give a full stack dump on any untrapped exceptions
@@ -40,7 +40,7 @@ local $SIG{ __WARN__ } = sub {
 
 # Useful common code
 
-use parent     qw( Pg::SQL::PrettyPrinter::Node );
+use parent qw( Pg::SQL::PrettyPrinter::Node );
 use List::Util qw( any );
 
 sub new {
@@ -55,17 +55,16 @@ sub new {
     }
 
     $self->objectify( 'name', 'rexpr', 'lexpr' );
-    use Data::Dumper;
     return $self;
 }
 
 sub operator {
     my $self = shift;
     if ( 1 == scalar @{ $self->{ 'name' } } ) {
-        return $self->{ 'name' }->[ 0 ]->string;
+        return $self->{ 'name' }->[ 0 ]->{ 'str' };
     }
     my @elements = map { $_->as_ident() } @{ $self->{ 'name' } };
-    $elements[ -1 ] = $self->{ 'name' }->[ -1 ]->string;
+    $elements[ -1 ] = $self->{ 'name' }->[ -1 ]->{ 'str' };
     return sprintf( "OPERATOR( %s )", join( '.', @elements ) );
 }
 
@@ -73,11 +72,9 @@ sub as_text {
     my $self = shift;
 
     if ( $self->{ 'kind' } eq 'AEXPR_IN' ) {
-        my $op = $self->operator eq '<>' ? 'NOT IN' : 'IN';
         return sprintf(
-            '%s %s %s',
+            '%s IN %s',
             $self->{ 'lexpr' }->as_text,
-            $op,
             $self->{ 'rexpr' }->as_text
         );
     }
@@ -121,11 +118,9 @@ sub as_text {
         );
     }
     elsif ( $self->{ 'kind' } eq 'AEXPR_LIKE' ) {
-        my $op = $self->operator eq '!~~' ? 'NOT LIKE' : 'LIKE';
         return sprintf(
-            '%s %s %s',
+            '%s LIKE %s',
             $self->{ 'lexpr' }->as_text,
-            $op,
             $self->{ 'rexpr' }->as_text,
         );
     }
@@ -194,11 +189,9 @@ sub as_text {
 sub pretty_print {
     my $self = shift;
     if ( $self->{ 'kind' } eq 'AEXPR_IN' ) {
-        my $op = $self->operator eq '<>' ? 'NOT IN' : 'IN';
         return sprintf(
-            '%s %s %s',
+            '%s IN %s',
             $self->{ 'lexpr' }->pretty_print,
-            $op,
             $self->{ 'rexpr' }->pretty_print
         );
     }
@@ -242,11 +235,9 @@ sub pretty_print {
         );
     }
     elsif ( $self->{ 'kind' } eq 'AEXPR_LIKE' ) {
-        my $op = $self->operator eq '!~~' ? 'NOT LIKE' : 'LIKE';
         return sprintf(
-            '%s %s %s',
+            '%s LIKE %s',
             $self->{ 'lexpr' }->pretty_print,
-            $op,
             $self->{ 'rexpr' }->pretty_print,
         );
     }
