@@ -21,8 +21,8 @@ if ( grep /\P{ASCII}/ => @ARGV ) {
 
 # Useful common code
 use autodie;
-use Carp         qw( carp croak confess cluck );
-use English      qw( -no_match_vars );
+use Carp qw( carp croak confess cluck );
+use English qw( -no_match_vars );
 use Data::Dumper qw( Dumper );
 
 # give a full stack dump on any untrapped exceptions
@@ -71,7 +71,6 @@ sub new {
         'funcname',
         'args',
         'agg_filter',
-        'agg_order',
         map { [ 'over', $_ ] } qw( orderClause partitionClause startOffset endOffset )
     );
 
@@ -246,35 +245,22 @@ sub frame_clause {
 sub as_text {
     my $self = shift;
 
-    my $suffix = $self->over_clause_as_text // '';
-    if ( exists $self->{ 'agg_filter' } ) {
-        $suffix .= ' FILTER ( WHERE ' . $self->{ 'agg_filter' }->as_text . ' )';
-    }
-    my $agg_order = $self->get_agg_order();
+    my $over_clause = $self->over_clause_as_text // '';
 
-    if ( $self->{ 'agg_star' } ) {
-        my $internal = $agg_order ? " * ${agg_order} " : '*';
-        return sprintf( '%s(%s)%s', $self->func_name, $internal, $suffix );
-    }
-    unless ( exists $self->{ 'args' } ) {
-        return $self->func_name . '()' . $suffix unless $agg_order;
-        return $self->func_name . "( ${agg_order} )" . $suffix;
-    }
+    return $self->func_name . '(*)' . $over_clause if $self->{ 'agg_star' };
+    return $self->func_name . '()' . $over_clause unless exists $self->{ 'args' };
 
     my @args_as_text = map { $_->as_text } @{ $self->{ 'args' } };
     if ( $self->{ 'func_variadic' } ) {
         $args_as_text[ -1 ] = 'VARIADIC ' . $args_as_text[ -1 ];
     }
     my $args_str = join( ', ', @args_as_text );
-    $args_str .= ' ' . $agg_order       if $agg_order;
-    $args_str = 'DISTINCT ' . $args_str if $self->{ 'agg_distinct' };
-    return $self->func_name . '( ' . $args_str . ' )' . $suffix;
-}
-
-sub get_agg_order {
-    my $self = shift;
-    return '' unless exists $self->{ 'agg_order' };
-    return sprintf( 'ORDER BY %s', join( ', ', map { $_->as_text } @{ $self->{ 'agg_order' } } ) );
+    if ( exists $self->{ 'agg_filter' } ) {
+        return $self->func_name . '( ' . $args_str . ' )' . $over_clause . ' FILTER ( WHERE ' . $self->{ 'agg_filter' }->as_text . ' )';
+    }
+    else {
+        return $self->func_name . '( ' . $args_str . ' )' . $over_clause;
+    }
 }
 
 sub pretty_print {
@@ -284,29 +270,18 @@ sub pretty_print {
     if ( exists $self->{ 'agg_filter' } ) {
         $suffix .= ' FILTER ( WHERE ' . $self->{ 'agg_filter' }->as_text . ' )';
     }
-    my $agg_order = $self->get_agg_order();
 
-    if ( $self->{ 'agg_star' } ) {
-        my $internal = $agg_order ? " * ${agg_order} " : '*';
-        return sprintf( '%s(%s)%s', $self->func_name, $internal, $suffix );
-    }
-    unless ( exists $self->{ 'args' } ) {
-        return $self->func_name . '()' . $suffix unless $agg_order;
-        return $self->func_name . "( ${agg_order} )" . $suffix;
-    }
+    return $self->func_name . '(*)' . $suffix if $self->{ 'agg_star' };
+    return $self->func_name . '()' . $suffix unless exists $self->{ 'args' };
 
     my @args_as_text = map { $_->as_text } @{ $self->{ 'args' } };
     if ( $self->{ 'func_variadic' } ) {
         $args_as_text[ -1 ] = 'VARIADIC ' . $args_as_text[ -1 ];
     }
     my $args_str = join( ', ', @args_as_text );
-    $args_str .= ' ' . $agg_order if $agg_order;
     if (   ( 1 == scalar @{ $self->{ 'args' } } )
         && ( 40 > length( $args_str ) ) )
     {
-        if ( $self->{ 'agg_distinct' } ) {
-            $args_str = 'DISTINCT ' . $args_str;
-        }
         return $self->func_name . '( ' . $args_str . ' )' . $suffix;
     }
     my @lines = ();
@@ -315,12 +290,8 @@ sub pretty_print {
     if ( $self->{ 'func_variadic' } ) {
         $args_pp[ -1 ] = 'VARIADIC ' . $args_pp[ -1 ];
     }
-    if ( $self->{ 'agg_distinct' } ) {
-        $args_pp[ 0 ] = 'DISTINCT ' . $args_pp[ 0 ];
-    }
     push @lines, map { $self->increase_indent( $_ ) . ',' } @args_pp;
     $lines[ -1 ] =~ s/,\z//;
-    push @lines, $self->increase_indent( $agg_order ) if $agg_order;
     push @lines, ')' . $suffix;
     return join( "\n", @lines );
 }
