@@ -21,8 +21,8 @@ if ( grep /\P{ASCII}/ => @ARGV ) {
 
 # Useful common code
 use autodie;
-use Carp         qw( carp croak confess cluck );
-use English      qw( -no_match_vars );
+use Carp qw( carp croak confess cluck );
+use English qw( -no_match_vars );
 use Data::Dumper qw( Dumper );
 
 # give a full stack dump on any untrapped exceptions
@@ -91,17 +91,7 @@ sub pretty_print {
         $join_cond = 'USING ( ' . join( ', ', map { $_->as_ident } @{ $self->{ 'usingClause' } } ) . ' )';
     }
     elsif ( $self->{ 'quals' } ) {
-        my $Q        = $self->{ 'quals' };
-        my $q_text   = $Q->as_text;
-        my $q_pretty = $Q->pretty_print;
-
-        # If join condition is multiline, indent it in nicer way.
-        if ( $q_pretty =~ /\n/ ) {
-            $join_cond = sprintf( "ON\n%s", $self->increase_indent( $q_pretty ) );
-        }
-        else {
-            $join_cond = 'ON ' . $q_pretty if $q_pretty !~ /\n/;
-        }
+        $join_cond = 'ON ' . $self->{ 'quals' }->pretty_print;
     }
     return sprintf "%s\n%s %s %s", $self->{ 'larg' }->pretty_print, $self->join_type, $self->{ 'rarg' }->pretty_print, $join_cond;
 }
