@@ -21,8 +21,8 @@ if ( grep /\P{ASCII}/ => @ARGV ) {
 
 # Useful common code
 use autodie;
-use Carp         qw( carp croak confess cluck );
-use English      qw( -no_match_vars );
+use Carp qw( carp croak confess cluck );
+use English qw( -no_match_vars );
 use Data::Dumper qw( Dumper );
 
 # give a full stack dump on any untrapped exceptions
@@ -59,9 +59,6 @@ sub as_text {
     my $self      = shift;
     my $full_name = $self->{ 'functions' }->[ 0 ]->{ 'items' }->[ 0 ]->as_text;
 
-    # Add optional WITH ORDINALITY
-    $full_name .= ' WITH ORDINALITY' if $self->{ 'ordinality' };
-
     # Shortcut
     my $A = $self->{ 'alias' };
     return $full_name unless $A;
