@@ -21,8 +21,8 @@ if ( grep /\P{ASCII}/ => @ARGV ) {
 
 # Useful common code
 use autodie;
-use Carp         qw( carp croak confess cluck );
-use English      qw( -no_match_vars );
+use Carp qw( carp croak confess cluck );
+use English qw( -no_match_vars );
 use Data::Dumper qw( Dumper );
 
 # give a full stack dump on any untrapped exceptions
@@ -42,18 +42,13 @@ local $SIG{ __WARN__ } = sub {
 
 use parent qw( Pg::SQL::PrettyPrinter::Node );
 
-sub string {
-    my $self = shift;
-    return $self->{ 'str' } // $self->{ 'sval' } // '';
-}
-
 sub as_text {
     my $self = shift;
-    return $self->quote_literal( $self->string );
+    return $self->quote_literal( $self->{ 'str' } // '' );
 }
 
 sub as_ident {
     my $self = shift;
-    return $self->quote_ident( $self->string );
+    return $self->quote_ident( $self->{ 'str' } // '' );
 }
 1;
